import { Construct } from 'constructs';
export declare const vssDatatypeMapping: {
    vssType: string;
    fleetWiseType: string;
}[];
export declare class SignalCatalogNode {
    protected node: object;
    constructor();
    toObject(): object;
}
export interface SignalCatalogBranchProps {
    readonly description?: string;
    readonly fullyQualifiedName: string;
}
export declare class SignalCatalogBranch extends SignalCatalogNode {
    constructor(props: SignalCatalogBranchProps);
}
export interface SignalCatalogSensorProps {
    readonly allowedValues?: string[];
    readonly dataType: string;
    readonly description?: string;
    readonly fullyQualifiedName: string;
    readonly max?: number;
    readonly min?: number;
    readonly unit?: string;
}
export declare class SignalCatalogSensor extends SignalCatalogNode {
    constructor(props: SignalCatalogSensorProps);
}
export interface SignalCatalogActuatorProps {
    readonly allowedValues?: string[];
    readonly assignedValue?: string;
    readonly dataType: string;
    readonly description?: string;
    readonly fullyQualifiedName: string;
    readonly max?: number;
    readonly min?: number;
    readonly unit?: string;
}
export declare class SignalCatalogActuator extends SignalCatalogNode {
    constructor(props: SignalCatalogActuatorProps);
}
export interface SignalCatalogAttributeProps {
    readonly allowedValues?: string[];
    readonly assignedValue?: string;
    readonly dataType: string;
    readonly defaultValue?: string;
    readonly description?: string;
    readonly fullyQualifiedName: string;
    readonly max?: number;
    readonly min?: number;
    readonly unit?: string;
}
export declare class SignalCatalogAttribute extends SignalCatalogNode {
    constructor(props: SignalCatalogAttributeProps);
}
/**
 * @summary The properties for the SignalCatalog construct.
 */
export interface SignalCatalogProps {
    /**
     * Name of the Signal Catalog. If not provided, default value is used.
     *
     * @default - default
     */
    readonly name?: string;
    /**
     * Description of the Signal Catalog. If not provided no description is set.
     *
     * @default - None
     */
    readonly description?: string;
    /**
     * Timestream database construct. If the construct is provided along with the `table` value,
     * the stack will attempt to register FleetWise.
     *
     * @default - None
     */
    /**
     * Deregister FleetWise on stack deletion. If set to 'true',  FleetWise will be deregistered from the Timestream
     * destination.
     *
     * @default - false
     */
    readonly deregister?: boolean;
    /**
     * An array of signal nodes. Nodes are a general abstraction of a signal.
     * A node can be specified as an actuator, attribute, branch, or sensor. See `SignalCatalogBranch`,
     * `SignalCatalogSensor`, `SignalCatalogActuator`, or `SignalCatalogAttribute` for creating nodes.
     *
     * @default - []
     */
    readonly nodes?: SignalCatalogNode[];
    /**
     * A YAML file that conforms to the [Vehicle Signal Specification format](https://covesa.github.io/vehicle_signal_specification/) and
     * contains a list of signals. If provided, the contents of the file, along with the `prefix` property will be
     * appended after any `SignalCatalogNode` objects provided.
     *
     * @default - None
     */
    readonly vssFile?: string;
    /**
     * A prefix to prepend to the fully qualified names found in the VSS file. The format of the prefix
     * is in dotted notation, and will be the prepended to all signal names.
     *
     * For instance, with the prefix of `OBD.MyData` and signal names of `PidA` and `PidB` will be combined
     * to create `OBD.MyData.PidA` and `OBD.MyData.PidB`.
     *
     * @default - None
     */
    readonly vssPrefix?: string;
    /**
     * If set to true, this will parse the vssPrefix into branch nodes. For instance if `OBD.MyData` was
     * provided,  the `OBD.MyData` will be parsed into branch nodes of `OBD` and `OBD.MyData`. By default
     * this is set to true. If you define branches in another way such as via `SignalCatalogNode`, set this
     * to false to suppress creation of branch nodes.
     *
     * @default - true
     */
    readonly vssGeneratePrefixBranch?: boolean;
}
/**
 * The Signal Catalog represents the list of all signals that you want to collect from all
 * the vehicles.
 *
 *
 * The AWS IoT Fleetwise preview can only support a single Signal Catalog per account.
 *
 */
export declare class SignalCatalog extends Construct {
    /**
     * The name of the signal catalog
     */
    readonly name: string;
    readonly description: string;
    private vssFile;
    private vssPrefix;
    private vssGeneratePrefixBranch;
    private nodes;
    readonly arn: string;
    constructor(scope: Construct, id: string, props: SignalCatalogProps);
}
